@@ -3,6 +3,7 @@ import requests
 from .Record import Record
 from .baseapi import BaseAPI
 
+
 class Domain(BaseAPI):
     def __init__(self, *args, **kwargs):
         self.name = None
@@ -24,9 +25,10 @@ class Domain(BaseAPI):
     def load(self):
         # URL https://api.digitalocean.com/v2/domains
         domains = self.get_data("domains/%s" % self.name)
+        domain = domains['domain']
 
-        for attr in domains.keys():
-            setattr(self,attr,domains[attr])
+        for attr in domain.keys():
+            setattr(self, attr, domain[attr])
 
     def destroy(self):
         """
@@ -61,7 +63,7 @@ class Domain(BaseAPI):
             "data": kwargs.get("data", None)
         }
 
-        # Optional Args
+        #  Optional Args
         if kwargs.get("priority", None):
             data['priority'] = kwargs.get("priority", None)
 
@@ -83,9 +85,9 @@ class Domain(BaseAPI):
         """
         # URL https://api.digitalocean.com/v2/domains
         data = {
-                "name": self.name,
-                "ip_address": self.ip_address,
-            }
+            "name": self.name,
+            "ip_address": self.ip_address,
+        }
 
         domain = self.get_data(
             "domains",
@@ -114,4 +116,4 @@ class Domain(BaseAPI):
         return records
 
     def __str__(self):
-        return "%s" % self.name
\ No newline at end of file
+        return "%s" % self.name
